summaryrefslogtreecommitdiff
path: root/Source/Core
diff options
context:
space:
mode:
authorGlenn Rice <glennricster@gmail.com>2011-02-14 02:18:03 +0000
committerGlenn Rice <glennricster@gmail.com>2011-02-14 02:18:03 +0000
commit0ae8d33149025435dd5eaf49f69abce2ad54887f (patch)
tree36f29de3e23d80e356f0cc5786368354d2cf2afc /Source/Core
parentcd308e2358c57acafd6b834352cebdcdb0b9e45d (diff)
Some work on changing comments, log messages, and variable and function names to reflect that the plugins are not plugins anymore.
git-svn-id: https://dolphin-emu.googlecode.com/svn/trunk@7170 8ced0084-cf51-0410-be5f-012b33b47a6e
Diffstat (limited to 'Source/Core')
-rw-r--r--Source/Core/AudioCommon/Src/AudioCommonConfig.cpp4
-rw-r--r--Source/Core/AudioCommon/Src/AudioCommonConfig.h2
-rw-r--r--Source/Core/AudioCommon/Src/Mixer.cpp4
-rw-r--r--Source/Core/Common/Src/CommonTypes.h6
-rw-r--r--Source/Core/Common/Src/FileUtil.h3
-rw-r--r--Source/Core/Common/Src/LogManager.cpp4
-rw-r--r--Source/Core/Common/Src/MathUtil.h2
-rw-r--r--Source/Core/Core/Src/Core.cpp14
-rw-r--r--Source/Core/Core/Src/CoreRerecording.cpp1
-rw-r--r--Source/Core/Core/Src/DSP/DSPCore.h2
-rw-r--r--Source/Core/Core/Src/DSPEmulator.h6
-rw-r--r--Source/Core/Core/Src/HW/AudioInterface.h2
-rw-r--r--Source/Core/Core/Src/HW/DSP.cpp2
-rw-r--r--Source/Core/Core/Src/HW/DSPHLE/DSPHLE.cpp2
-rw-r--r--Source/Core/Core/Src/HW/DSPHLE/UCodes/UCodes.cpp4
-rw-r--r--Source/Core/Core/Src/HW/VideoInterface.cpp2
-rw-r--r--Source/Core/Core/Src/OnFrame.cpp4
-rw-r--r--Source/Core/Core/Src/OnFrame.h6
-rw-r--r--Source/Core/Core/Src/PowerPC/Interpreter/Interpreter_LoadStore.cpp2
-rw-r--r--Source/Core/Core/Src/PowerPC/Jit64/Jit.cpp2
-rw-r--r--Source/Core/Core/Src/PowerPC/Jit64IL/JitIL.cpp2
-rw-r--r--Source/Core/Core/Src/State.cpp2
-rw-r--r--Source/Core/DolphinWX/Src/ConfigMain.cpp6
-rw-r--r--Source/Core/DolphinWX/Src/Debugger/CodeWindow.cpp3
-rw-r--r--Source/Core/DolphinWX/Src/Frame.cpp10
-rw-r--r--Source/Core/DolphinWX/Src/FrameTools.cpp8
-rw-r--r--Source/Core/DolphinWX/Src/Globals.h4
-rw-r--r--Source/Core/VideoCommon/Src/BPFunctions.cpp2
-rw-r--r--Source/Core/VideoCommon/Src/BPFunctions.h2
-rw-r--r--Source/Core/VideoCommon/Src/BPMemory.cpp2
-rw-r--r--Source/Core/VideoCommon/Src/CommandProcessor.cpp10
-rw-r--r--Source/Core/VideoCommon/Src/CommandProcessor.h4
-rw-r--r--Source/Core/VideoCommon/Src/Debugger.cpp2
-rw-r--r--Source/Core/VideoCommon/Src/EmuWindow.cpp2
-rw-r--r--Source/Core/VideoCommon/Src/Fifo.cpp4
-rw-r--r--Source/Core/VideoCommon/Src/Fifo.h2
-rw-r--r--Source/Core/VideoCommon/Src/IndexGenerator.h4
-rw-r--r--Source/Core/VideoCommon/Src/MainBase.cpp8
-rw-r--r--Source/Core/VideoCommon/Src/MainBase.h2
-rw-r--r--Source/Core/VideoCommon/Src/NativeVertexFormat.h2
-rw-r--r--Source/Core/VideoCommon/Src/OpcodeDecoding.cpp2
-rw-r--r--Source/Core/VideoCommon/Src/OpcodeDecoding.h2
-rw-r--r--Source/Core/VideoCommon/Src/OpenCL.cpp2
-rw-r--r--Source/Core/VideoCommon/Src/PixelEngine.cpp4
-rw-r--r--Source/Core/VideoCommon/Src/PixelEngine.h2
-rw-r--r--Source/Core/VideoCommon/Src/VertexManagerBase.h6
-rw-r--r--Source/Core/VideoCommon/Src/VideoCommon.h2
-rw-r--r--Source/Core/VideoCommon/Src/VideoConfig.cpp2
-rw-r--r--Source/Core/VideoCommon/Src/VideoConfig.h6
49 files changed, 86 insertions, 97 deletions
diff --git a/Source/Core/AudioCommon/Src/AudioCommonConfig.cpp b/Source/Core/AudioCommon/Src/AudioCommonConfig.cpp
index 6e22512c06..b04ae01fd9 100644
--- a/Source/Core/AudioCommon/Src/AudioCommonConfig.cpp
+++ b/Source/Core/AudioCommon/Src/AudioCommonConfig.cpp
@@ -43,7 +43,7 @@ void AudioCommonConfig::Load()
#else
file.Get("Config", "Backend", &sBackend, BACKEND_NULLSOUND);
#endif
- file.Get("Config", "Frequency", &sFrequency, 48000);
+ file.Get("Config", "Frequency", &iFrequency, 48000);
file.Get("Config", "Volume", &m_Volume, 100);
}
@@ -58,7 +58,7 @@ void AudioCommonConfig::SaveSettings()
file.Set("Config", "EnableJIT", m_EnableJIT);
file.Set("Config", "DumpAudio", m_DumpAudio);
file.Set("Config", "Backend", sBackend);
- file.Set("Config", "Frequency", sFrequency);
+ file.Set("Config", "Frequency", iFrequency);
file.Set("Config", "Volume", m_Volume);
file.Save((std::string(File::GetUserPath(F_DSPCONFIG_IDX)).c_str()));
diff --git a/Source/Core/AudioCommon/Src/AudioCommonConfig.h b/Source/Core/AudioCommon/Src/AudioCommonConfig.h
index 98cbf60500..49124344e0 100644
--- a/Source/Core/AudioCommon/Src/AudioCommonConfig.h
+++ b/Source/Core/AudioCommon/Src/AudioCommonConfig.h
@@ -39,7 +39,7 @@ struct AudioCommonConfig
bool m_DumpAudio;
int m_Volume;
std::string sBackend;
- int sFrequency;
+ int iFrequency;
// Load from given file
void Load();
diff --git a/Source/Core/AudioCommon/Src/Mixer.cpp b/Source/Core/AudioCommon/Src/Mixer.cpp
index 8dcc972535..2833a029dd 100644
--- a/Source/Core/AudioCommon/Src/Mixer.cpp
+++ b/Source/Core/AudioCommon/Src/Mixer.cpp
@@ -194,10 +194,8 @@ void CMixer::PushSamples(const short *samples, unsigned int num_samples)
if (m_sampleRate == 32000)
Common::AtomicAdd(m_numSamples, num_samples);
- else if (m_sampleRate == 48000)
+ else // Assume 48000 otherwise
Common::AtomicAdd(m_numSamples, num_samples * 3 / 2);
- else
- PanicAlertT("Mixer: Unsupported sample rate.");
return;
}
diff --git a/Source/Core/Common/Src/CommonTypes.h b/Source/Core/Common/Src/CommonTypes.h
index 2482a8822d..71bc9386ac 100644
--- a/Source/Core/Common/Src/CommonTypes.h
+++ b/Source/Core/Common/Src/CommonTypes.h
@@ -16,9 +16,9 @@
// http://code.google.com/p/dolphin-emu/
-// This header contains type definitions that are shared between the Dolphin
-// core and the plugin specs. Any definitions that are only used by the core
-// should be placed in "Common.h" instead.
+// This header contains type definitions that are shared between the Dolphin core and
+// other parts of the code. Any definitions that are only used by the core should be
+// placed in "Common.h" instead.
#ifndef _COMMONTYPES_H_
#define _COMMONTYPES_H_
diff --git a/Source/Core/Common/Src/FileUtil.h b/Source/Core/Common/Src/FileUtil.h
index 588e0550b7..ff9277645f 100644
--- a/Source/Core/Common/Src/FileUtil.h
+++ b/Source/Core/Common/Src/FileUtil.h
@@ -129,9 +129,6 @@ bool SetCurrentDir(const char *directory);
// directory. To be used in "multi-user" mode (that is, installed).
const char *GetUserPath(int DirIDX);
-// Returns the path to where the plugins are
-std::string GetPluginsDirectory();
-
// Returns the path to where the sys file are
std::string GetSysDirectory();
diff --git a/Source/Core/Common/Src/LogManager.cpp b/Source/Core/Common/Src/LogManager.cpp
index cdf9a99acb..b0eae86504 100644
--- a/Source/Core/Common/Src/LogManager.cpp
+++ b/Source/Core/Common/Src/LogManager.cpp
@@ -64,8 +64,8 @@ LogManager::LogManager() {
m_Log[LogTypes::DSPHLE] = new LogContainer("DSPHLE", "DSP HLE");
m_Log[LogTypes::DSPLLE] = new LogContainer("DSPLLE", "DSP LLE");
m_Log[LogTypes::DSP_MAIL] = new LogContainer("DSPMails", "DSP Mails");
- m_Log[LogTypes::VIDEO] = new LogContainer("Video", "Video Plugin");
- m_Log[LogTypes::AUDIO] = new LogContainer("Audio", "Audio Plugin");
+ m_Log[LogTypes::VIDEO] = new LogContainer("Video", "Video Backend");
+ m_Log[LogTypes::AUDIO] = new LogContainer("Audio", "Audio Emulator");
m_Log[LogTypes::DYNA_REC] = new LogContainer("JIT", "Dynamic Recompiler");
m_Log[LogTypes::CONSOLE] = new LogContainer("CONSOLE", "Dolphin Console");
m_Log[LogTypes::OSREPORT] = new LogContainer("OSREPORT", "OSReport");
diff --git a/Source/Core/Common/Src/MathUtil.h b/Source/Core/Common/Src/MathUtil.h
index 95fbbc24ba..da56becc42 100644
--- a/Source/Core/Common/Src/MathUtil.h
+++ b/Source/Core/Common/Src/MathUtil.h
@@ -157,7 +157,7 @@ float MathFloatVectorSum(const std::vector<float>&);
// Tiny matrix/vector library.
-// Used for things like Free-Look in the gfx plugin.
+// Used for things like Free-Look in the gfx backend.
class Matrix33
{
diff --git a/Source/Core/Core/Src/Core.cpp b/Source/Core/Core/Src/Core.cpp
index 6a52dc2d60..b0c10a57ab 100644
--- a/Source/Core/Core/Src/Core.cpp
+++ b/Source/Core/Core/Src/Core.cpp
@@ -274,7 +274,7 @@ void CpuThread()
}
-// Initalize plugins and create emulation thread
+// Initalize and create emulation thread
// Call browser: Init():g_EmuThread(). See the BootManager.cpp file description for a complete call schedule.
void EmuThread()
{
@@ -367,7 +367,7 @@ void EmuThread()
{
// the spawned CPU Thread also does the graphics. the EmuThread is
// thus an idle thread, which sleep wait for the program to terminate.
- // Without this extra thread, the video plugin window hangs in single
+ // Without this extra thread, the video backend window hangs in single
// core mode since noone is pumping messages.
cpuThread = std::thread(CpuThread);
@@ -409,8 +409,8 @@ void EmuThread()
VolumeHandler::EjectVolume();
FileMon::Close();
- // Stop audio thread - Actually this does nothing on HLE plugin.
- // But stops the DSP Interpreter on LLE plugin.
+ // Stop audio thread - Actually this does nothing when using HLE emulation.
+ // But stops the DSP Interpreter when using LLE emulation.
DSP::GetDSPEmulator()->DSP_StopSoundStream();
// We must set up this flag before executing HW::Shutdown()
@@ -426,8 +426,6 @@ void EmuThread()
Pad::Shutdown();
Wiimote::Shutdown();
- INFO_LOG(CONSOLE, "%s", StopMessage(false, "Plugins shutdown").c_str());
-
INFO_LOG(CONSOLE, "%s", StopMessage(true, "Main thread stopped").c_str());
INFO_LOG(CONSOLE, "Stop [Main Thread]\t\t---- Shutdown complete ----");
@@ -613,7 +611,7 @@ bool report_slow(int skipped)
return fps_slow;
}
-// --- Callbacks for plugins / engine ---
+// --- Callbacks for backends / engine ---
// Callback_VideoLog
// WARNING - THIS IS EXECUTED FROM VIDEO THREAD
@@ -660,7 +658,7 @@ void Callback_DSPInterrupt()
}
-// Callback_ISOName: Let the DSP plugin get the game name
+// Callback_ISOName: Let the DSP emulator get the game name
//
const char *Callback_ISOName()
{
diff --git a/Source/Core/Core/Src/CoreRerecording.cpp b/Source/Core/Core/Src/CoreRerecording.cpp
index 351963f315..3064ed37ad 100644
--- a/Source/Core/Core/Src/CoreRerecording.cpp
+++ b/Source/Core/Core/Src/CoreRerecording.cpp
@@ -54,7 +54,6 @@ bool rerecording = false;
#include "PowerPC/PowerPC.h"
-#include "PluginManager.h"
#include "ConfigManager.h"
#include "MemTools.h"
diff --git a/Source/Core/Core/Src/DSP/DSPCore.h b/Source/Core/Core/Src/DSP/DSPCore.h
index 2f69eb6ee6..feb82bce9f 100644
--- a/Source/Core/Core/Src/DSP/DSPCore.h
+++ b/Source/Core/Core/Src/DSP/DSPCore.h
@@ -225,7 +225,7 @@ struct SDSP
// This is NOT the same cr as r.cr.
// This register is shared with the main emulation, see DSP.cpp
- // The plugin has control over 0x0C07 of this reg.
+ // The engine has control over 0x0C07 of this reg.
// Bits are defined in a struct in DSP.cpp.
u16 cr;
diff --git a/Source/Core/Core/Src/DSPEmulator.h b/Source/Core/Core/Src/DSPEmulator.h
index 8d2a108e18..07d83da177 100644
--- a/Source/Core/Core/Src/DSPEmulator.h
+++ b/Source/Core/Core/Src/DSPEmulator.h
@@ -15,8 +15,8 @@
// Official SVN repository and contact information can be found at
// http://code.google.com/p/dolphin-emu/
-#ifndef _PLUGINDSP_H_
-#define _PLUGINDSP_H_
+#ifndef _DSPEMULATOR_H_
+#define _DSPEMULATOR_H_
#include "ChunkFile.h"
@@ -47,4 +47,4 @@ public:
DSPEmulator *CreateDSPEmulator(bool LLE);
-#endif // _PLUGINDSP_H_
+#endif // _DSPEMULATOR_H_
diff --git a/Source/Core/Core/Src/HW/AudioInterface.h b/Source/Core/Core/Src/HW/AudioInterface.h
index 9c36826042..8f01e9f7e7 100644
--- a/Source/Core/Core/Src/HW/AudioInterface.h
+++ b/Source/Core/Core/Src/HW/AudioInterface.h
@@ -33,7 +33,7 @@ void DoState(PointerWrap &p);
void Update();
-// Called by DSP plugin
+// Called by DSP emulator
void Callback_GetSampleRate(unsigned int &_AISampleRate, unsigned int &_DACSampleRate);
unsigned int Callback_GetStreaming(short* _pDestBuffer, unsigned int _numSamples, unsigned int _sampleRate = 48000);
diff --git a/Source/Core/Core/Src/HW/DSP.cpp b/Source/Core/Core/Src/HW/DSP.cpp
index 21475551d8..41f371cee2 100644
--- a/Source/Core/Core/Src/HW/DSP.cpp
+++ b/Source/Core/Core/Src/HW/DSP.cpp
@@ -412,7 +412,7 @@ void Write16(const u16 _Value, const u32 _Address)
// Not really sure if this is correct, but it works...
// Kind of a hack because DSP_CONTROL_MASK should make this bit
- // only viewable to dsp plugin
+ // only viewable to dsp emulator
if (_Value & 1 /*DSPReset*/)
{
g_audioDMA.AudioDMAControl.Hex = 0;
diff --git a/Source/Core/Core/Src/HW/DSPHLE/DSPHLE.cpp b/Source/Core/Core/Src/HW/DSPHLE/DSPHLE.cpp
index ac3b06e0f8..fab709d8b9 100644
--- a/Source/Core/Core/Src/HW/DSPHLE/DSPHLE.cpp
+++ b/Source/Core/Core/Src/HW/DSPHLE/DSPHLE.cpp
@@ -196,7 +196,7 @@ u16 DSPHLE::DSP_WriteControlRegister(unsigned short _Value)
AudioInterface::Callback_GetSampleRate(AISampleRate, DACSampleRate);
soundStream = AudioCommon::InitSoundStream(
- new HLEMixer(this, AISampleRate, DACSampleRate, ac_Config.sFrequency), m_hWnd);
+ new HLEMixer(this, AISampleRate, DACSampleRate, ac_Config.iFrequency), m_hWnd);
if(!soundStream) PanicAlert("Error starting up sound stream");
// Mixer is initialized
m_InitMixer = true;
diff --git a/Source/Core/Core/Src/HW/DSPHLE/UCodes/UCodes.cpp b/Source/Core/Core/Src/HW/DSPHLE/UCodes/UCodes.cpp
index c93b7754dd..34f8e107ca 100644
--- a/Source/Core/Core/Src/HW/DSPHLE/UCodes/UCodes.cpp
+++ b/Source/Core/Core/Src/HW/DSPHLE/UCodes/UCodes.cpp
@@ -94,12 +94,12 @@ IUCode* UCodeFactory(u32 _CRC, DSPHLE *dsp_hle, bool bWii)
default:
if (bWii)
{
- PanicAlert("DSPHLE: Unknown ucode (CRC = %08x) - forcing AXWii.\n\nTry LLE plugin if this is homebrew.", _CRC);
+ PanicAlert("DSPHLE: Unknown ucode (CRC = %08x) - forcing AXWii.\n\nTry LLE emulator if this is homebrew.", _CRC);
return new CUCode_AXWii(dsp_hle, _CRC);
}
else
{
- PanicAlert("DSPHLE: Unknown ucode (CRC = %08x) - forcing AX.\n\nTry LLE plugin if this is homebrew.", _CRC);
+ PanicAlert("DSPHLE: Unknown ucode (CRC = %08x) - forcing AX.\n\nTry LLE emulator if this is homebrew.", _CRC);
return new CUCode_AX(dsp_hle);
}
}
diff --git a/Source/Core/Core/Src/HW/VideoInterface.cpp b/Source/Core/Core/Src/HW/VideoInterface.cpp
index c1d0c2607f..4dc589397c 100644
--- a/Source/Core/Core/Src/HW/VideoInterface.cpp
+++ b/Source/Core/Core/Src/HW/VideoInterface.cpp
@@ -413,7 +413,7 @@ void Write16(const u16 _iValue, const u32 _iAddress)
{
DEBUG_LOG(VIDEOINTERFACE, "(w16): 0x%04x, 0x%08x",_iValue,_iAddress);
- //Somewhere it sets screen width.. we need to communicate this to the gfx plugin...
+ //Somewhere it sets screen width.. we need to communicate this to the gfx backend...
switch (_iAddress & 0xFFF)
{
diff --git a/Source/Core/Core/Src/OnFrame.cpp b/Source/Core/Core/Src/OnFrame.cpp
index bd88c92012..311912649c 100644
--- a/Source/Core/Core/Src/OnFrame.cpp
+++ b/Source/Core/Core/Src/OnFrame.cpp
@@ -477,8 +477,8 @@ void SaveRecording(const char *filename)
// TODO
header.uniqueID = 0;
// header.author;
- // header.videoPlugin;
- // header.audioPlugin;
+ // header.videoBackend;
+ // header.audioEmulator;
fwrite(&header, sizeof(DTMHeader), 1, g_recordfd);
}
diff --git a/Source/Core/Core/Src/PowerPC/Interpreter/Interpreter_LoadStore.cpp b/Source/Core/Core/Src/PowerPC/Interpreter/Interpreter_LoadStore.cpp
index df00df12b4..5d7cd28b20 100644
--- a/Source/Core/Core/Src/PowerPC/Interpreter/Interpreter_LoadStore.cpp
+++ b/Source/Core/Core/Src/PowerPC/Interpreter/Interpreter_LoadStore.cpp
@@ -353,7 +353,7 @@ void Interpreter::dcba(UGeckoInstruction _inst)
void Interpreter::dcbf(UGeckoInstruction _inst)
{
- //This should tell GFX plugin to throw out any cached data here
+ //This should tell GFX backend to throw out any cached data here
// !!! SPEEDUP HACK for OSProtectRange !!!
/* u32 tmp1 = Memory::Read_U32(PC+4);
u32 tmp2 = Memory::Read_U32(PC+8);
diff --git a/Source/Core/Core/Src/PowerPC/Jit64/Jit.cpp b/Source/Core/Core/Src/PowerPC/Jit64/Jit.cpp
index 79c140875a..0c57c54e1b 100644
--- a/Source/Core/Core/Src/PowerPC/Jit64/Jit.cpp
+++ b/Source/Core/Core/Src/PowerPC/Jit64/Jit.cpp
@@ -93,7 +93,7 @@ using namespace PowerPC;
// Seldom-happening events is handled by adding a decrement of a counter to all blr instructions (which are
// expensive anyway since we need to return to dispatcher, except when they can be predicted).
-// TODO: SERIOUS synchronization problem with the video plugin setting tokens and breakpoints in dual core mode!!!
+// TODO: SERIOUS synchronization problem with the video backend setting tokens and breakpoints in dual core mode!!!
// Somewhat fixed by disabling idle skipping when certain interrupts are enabled
// This is no permanent reliable fix
// TODO: Zeldas go whacko when you hang the gfx thread
diff --git a/Source/Core/Core/Src/PowerPC/Jit64IL/JitIL.cpp b/Source/Core/Core/Src/PowerPC/Jit64IL/JitIL.cpp
index 2bba5878f0..4890386421 100644
--- a/Source/Core/Core/Src/PowerPC/Jit64IL/JitIL.cpp
+++ b/Source/Core/Core/Src/PowerPC/Jit64IL/JitIL.cpp
@@ -88,7 +88,7 @@ using namespace PowerPC;
// Seldom-happening events is handled by adding a decrement of a counter to all blr instructions (which are
// expensive anyway since we need to return to dispatcher, except when they can be predicted).
-// TODO: SERIOUS synchronization problem with the video plugin setting tokens and breakpoints in dual core mode!!!
+// TODO: SERIOUS synchronization problem with the video backend setting tokens and breakpoints in dual core mode!!!
// Somewhat fixed by disabling idle skipping when certain interrupts are enabled
// This is no permanent reliable fix
// TODO: Zeldas go whacko when you hang the gfx thread
diff --git a/Source/Core/Core/Src/State.cpp b/Source/Core/Core/Src/State.cpp
index d65251fb7c..6bba6072f4 100644
--- a/Source/Core/Core/Src/State.cpp
+++ b/Source/Core/Core/Src/State.cpp
@@ -87,7 +87,7 @@ void DoState(PointerWrap &p)
p.SetMode(PointerWrap::MODE_MEASURE);
return;
}
- // Begin with video plugin, so that it gets a chance to clear it's caches and writeback modified things to RAM
+ // Begin with video backend, so that it gets a chance to clear it's caches and writeback modified things to RAM
// Pause the video thread in multi-threaded mode
g_video_backend->RunLoop(false);
g_video_backend->DoState(p);
diff --git a/Source/Core/DolphinWX/Src/ConfigMain.cpp b/Source/Core/DolphinWX/Src/ConfigMain.cpp
index 818db44198..02733826b6 100644
--- a/Source/Core/DolphinWX/Src/ConfigMain.cpp
+++ b/Source/Core/DolphinWX/Src/ConfigMain.cpp
@@ -235,7 +235,7 @@ void CConfigMain::UpdateGUI()
ProgressiveScan->Disable();
NTSCJ->Disable();
- // Disable graphics plugin selection
+ // Disable graphics backend selection
GraphicSelection->Disable();
// Disable stuff on AudioPage
@@ -403,7 +403,7 @@ void CConfigMain::InitializeGUIValues()
EnableThrottle->SetValue(ac_Config.m_EnableThrottle ? true : false);
DumpAudio->SetValue(ac_Config.m_DumpAudio ? true : false);
FrequencySelection->SetSelection(
- FrequencySelection->FindString(wxString::Format(_("%d Hz"), ac_Config.sFrequency)));
+ FrequencySelection->FindString(wxString::Format(_("%d Hz"), ac_Config.iFrequency)));
// add backends to the list
AddAudioBackends();
@@ -1082,7 +1082,7 @@ void CConfigMain::AudioSettingsChanged(wxCommandEvent& event)
ac_Config.sBackend = BackendSelection->GetStringSelection().mb_str();
long int frequency;
FrequencySelection->GetStringSelection().ToLong(&frequency);
- ac_Config.sFrequency = frequency;
+ ac_Config.iFrequency = frequency;
ac_Config.Update();
break;
}
diff --git a/Source/Core/DolphinWX/Src/Debugger/CodeWindow.cpp b/Source/Core/DolphinWX/Src/Debugger/CodeWindow.cpp
index 798de4a952..2e65cbc06a 100644
--- a/Source/Core/DolphinWX/Src/Debugger/CodeWindow.cpp
+++ b/Source/Core/DolphinWX/Src/Debugger/CodeWindow.cpp
@@ -66,9 +66,6 @@ extern "C" // Bitmaps
#include "../../resources/toolbar_add_breakpoint.c"
}
-class CPluginInfo;
-class CPluginManager;
-
// -------
// Main
diff --git a/Source/Core/DolphinWX/Src/FrameTools.cpp b/Source/Core/DolphinWX/Src/FrameTools.cpp
index e60d386819..518edffcfc 100644
--- a/Source/Core/DolphinWX/Src/FrameTools.cpp
+++ b/Source/Core/DolphinWX/Src/FrameTools.cpp
@@ -186,8 +186,8 @@ void CFrame::CreateMenu()
wxMenu* pOptionsMenu = new wxMenu;
pOptionsMenu->Append(wxID_PREFERENCES, _("Co&nfigure..."));
pOptionsMenu->AppendSeparator();
- pOptionsMenu->Append(IDM_CONFIG_GFX_PLUGIN, _("&Graphics Settings"));
- pOptionsMenu->Append(IDM_CONFIG_DSP_PLUGIN, _("&DSP Settings"));
+ pOptionsMenu->Append(IDM_CONFIG_GFX_BACKEND, _("&Graphics Settings"));
+ pOptionsMenu->Append(IDM_CONFIG_DSP_EMULATOR, _("&DSP Settings"));
pOptionsMenu->Append(IDM_CONFIG_PAD_PLUGIN, _("&Gamecube Pad Settings"));
pOptionsMenu->Append(IDM_CONFIG_WIIMOTE_PLUGIN, _("&Wiimote Settings"));
pOptionsMenu->Append(IDM_CONFIG_HOTKEYS, _("&Hotkey Settings"));
@@ -444,8 +444,8 @@ void CFrame::PopulateToolbar(wxAuiToolBar* ToolBar)
ToolBar->AddTool(IDM_SCREENSHOT, _("ScrShot"), m_Bitmaps[Toolbar_FullScreen], _("Take Screenshot"));
ToolBar->AddSeparator();
ToolBar->AddTool(wxID_PREFERENCES, _("Config"), m_Bitmaps[Toolbar_ConfigMain], _("Configure..."));
- ToolBar->AddTool(IDM_CONFIG_GFX_PLUGIN, _("Graphics"), m_Bitmaps[Toolbar_ConfigGFX], _("Graphics settings"));
- ToolBar->AddTool(IDM_CONFIG_DSP_PLUGIN, _("DSP"), m_Bitmaps[Toolbar_ConfigDSP], _("DSP settings"));
+ ToolBar->AddTool(IDM_CONFIG_GFX_BACKEND, _("Graphics"), m_Bitmaps[Toolbar_ConfigGFX], _("Graphics settings"));
+ ToolBar->AddTool(IDM_CONFIG_DSP_EMULATOR, _("DSP"), m_Bitmaps[Toolbar_ConfigDSP], _("DSP settings"));
ToolBar->AddTool(IDM_CONFIG_PAD_PLUGIN, _("GCPad"), m_Bitmaps[Toolbar_ConfigPAD], _("Gamecube Pad settings"));
ToolBar->AddTool(IDM_CONFIG_WIIMOTE_PLUGIN, _("Wiimote"), m_Bitmaps[Toolbar_Wiimote], _("Wiimote settings"));
diff --git a/Source/Core/DolphinWX/Src/Globals.h b/Source/Core/DolphinWX/Src/Globals.h
index 9b18bcd037..04ee7f80f9 100644
--- a/Source/Core/DolphinWX/Src/Globals.h
+++ b/Source/Core/DolphinWX/Src/Globals.h
@@ -116,8 +116,8 @@ enum
IDM_HELPWEBSITE, // Help menu
IDM_HELPGOOGLECODE,
- IDM_CONFIG_GFX_PLUGIN,
- IDM_CONFIG_DSP_PLUGIN,
+ IDM_CONFIG_GFX_BACKEND,
+ IDM_CONFIG_DSP_EMULATOR,
IDM_CONFIG_PAD_PLUGIN,
IDM_CONFIG_WIIMOTE_PLUGIN,
IDM_CONFIG_HOTKEYS,
diff --git a/Source/Core/VideoCommon/Src/BPFunctions.cpp b/Source/Core/VideoCommon/Src/BPFunctions.cpp
index 8e854b4690..5255b6cb54 100644
--- a/Source/Core/VideoCommon/Src/BPFunctions.cpp
+++ b/Source/Core/VideoCommon/Src/BPFunctions.cpp
@@ -88,7 +88,7 @@ void CopyEFB(const BPCmd &bp, const EFBRectangle &rc, const u32 &address, const
/* Explanation of the magic behind ClearScreen:
There's numerous possible formats for the pixel data in the EFB.
- However, in the HW accelerated plugins we're always using RGBA8
+ However, in the HW accelerated backends we're always using RGBA8
for the EFB format, which causes some problems:
- We're using an alpha channel although the game doesn't
- If the actual EFB format is RGBA6_Z24 or R5G6B5_Z16, we are using more bits per channel than the native HW
diff --git a/Source/Core/VideoCommon/Src/BPFunctions.h b/Source/Core/VideoCommon/Src/BPFunctions.h
index b38681a1b9..e2a184f65e 100644
--- a/Source/Core/VideoCommon/Src/BPFunctions.h
+++ b/Source/Core/VideoCommon/Src/BPFunctions.h
@@ -17,7 +17,7 @@
// ------------------------------------------
-// Video plugin must define these functions
+// Video backend must define these functions
// ------------------------------------------
#ifndef _BPFUNCTIONS_H
diff --git a/Source/Core/VideoCommon/Src/BPMemory.cpp b/Source/Core/VideoCommon/Src/BPMemory.cpp
index a232fc7fe5..da09893f35 100644
--- a/Source/Core/VideoCommon/Src/BPMemory.cpp
+++ b/Source/Core/VideoCommon/Src/BPMemory.cpp
@@ -22,7 +22,7 @@
// STATE_TO_SAVE
BPMemory bpmem;
-// The plugin must implement this.
+// The backend must implement this.
void BPWritten(const BPCmd& bp);
// Call browser: OpcodeDecoding.cpp ExecuteDisplayList > Decode() > LoadBPReg()
diff --git a/Source/Core/VideoCommon/Src/CommandProcessor.h b/Source/Core/VideoCommon/Src/CommandProcessor.h
index dc49cdf9fe..ec1d1234c3 100644
--- a/Source/Core/VideoCommon/Src/CommandProcessor.h
+++ b/Source/Core/VideoCommon/Src/CommandProcessor.h
@@ -157,9 +157,9 @@ void SetStatus();
void GatherPipeBursted();
void UpdateFifoRegister();
void UpdateInterrupts(u64 userdata);
-void UpdateInterruptsFromVideoPlugin(u64 userdata);
+void UpdateInterruptsFromVideoBackend(u64 userdata);
void UpdateInterruptsScMode();
-void SetFifoIdleFromVideoPlugin();
+void SetFifoIdleFromVideoBackend();
bool AllowIdleSkipping();
diff --git a/Source/Core/VideoCommon/Src/Debugger.cpp b/Source/Core/VideoCommon/Src/Debugger.cpp
index d723570fe5..b808c63c11 100644
--- a/Source/Core/VideoCommon/Src/Debugger.cpp
+++ b/Source/Core/VideoCommon/Src/Debugger.cpp
@@ -31,7 +31,7 @@ extern NativeVertexFormat *g_nativeVertexFmt;
void GFXDebuggerUpdateScreen()
{
- // TODO: Implement this in a plugin-independent way
+ // TODO: Implement this in a backend-independent way
/* // update screen
if (D3D::bFrameInProgress)
{
diff --git a/Source/Core/VideoCommon/Src/EmuWindow.cpp b/Source/Core/VideoCommon/Src/EmuWindow.cpp
index c92a4cacb1..4cd8bb007d 100644
--- a/Source/Core/VideoCommon/Src/EmuWindow.cpp
+++ b/Source/Core/VideoCommon/Src/EmuWindow.cpp
@@ -186,7 +186,7 @@ LRESULT CALLBACK WndProc( HWND hWnd, UINT iMsg, WPARAM wParam, LPARAM lParam )
// This is called when we close the window when we render to a separate window
case WM_CLOSE:
// When the user closes the window, we post an event to the main window to call Stop()
- // Which then handles all the necessary steps to Shutdown the core + the plugins
+ // Which then handles all the necessary steps to Shutdown the core
if (m_hParent == NULL)
{
// Stop the game
diff --git a/Source/Core/VideoCommon/Src/Fifo.h b/Source/Core/VideoCommon/Src/Fifo.h
index c4470b7208..90f0d9ed33 100644
--- a/Source/Core/VideoCommon/Src/Fifo.h
+++ b/Source/Core/VideoCommon/Src/Fifo.h
@@ -43,7 +43,7 @@ void ResetVideoBuffer();
void Fifo_SetRendering(bool bEnabled);
bool IsFifoProcesingData();
-// Implemented by the Video Plugin
+// Implemented by the Video Backend
void VideoFifo_CheckAsyncRequest();
void VideoFifo_CheckStateRequest();
diff --git a/Source/Core/VideoCommon/Src/IndexGenerator.h b/Source/Core/VideoCommon/Src/IndexGenerator.h
index 67871117b1..d1ed143d98 100644
--- a/Source/Core/VideoCommon/Src/IndexGenerator.h
+++ b/Source/Core/VideoCommon/Src/IndexGenerator.h
@@ -15,8 +15,8 @@
// Official SVN repository and contact information can be found at
// http://code.google.com/p/dolphin-emu/
-// This is currently only used by the DX plugin, but it may make sense to
-// use it in the GL plugin or a future DX10 plugin too.
+// This is currently only used by the DX backend, but it may make sense to
+// use it in the GL backend or a future DX10 backend too.
#ifndef _INDEXGENERATOR_H
#define _INDEXGENERATOR_H
diff --git a/Source/Core/VideoCommon/Src/MainBase.cpp b/Source/Core/VideoCommon/Src/MainBase.cpp
index 2316262b19..485db54f39 100644
--- a/Source/Core/VideoCommon/Src/MainBase.cpp
+++ b/Source/Core/VideoCommon/Src/MainBase.cpp
@@ -15,7 +15,7 @@
#include "VideoBackendBase.h"
#include "ConfigManager.h"
-bool s_PluginInitialized = false;
+bool s_BackendInitialized = false;
volatile u32 s_swapRequested = false;
u32 s_efbAccessRequested = false;
@@ -96,7 +96,7 @@ void VideoFifo_CheckSwapRequestAt(u32 xfbAddr, u32 fbWidth, u32 fbHeight)
// Run from the CPU thread (from VideoInterface.cpp)
void VideoBackendHLE::Video_BeginField(u32 xfbAddr, FieldType field, u32 fbWidth, u32 fbHeight)
{
- if (s_PluginInitialized && g_ActiveConfig.bUseXFB)
+ if (s_BackendInitialized && g_ActiveConfig.bUseXFB)
{
if (!SConfig::GetInstance().m_LocalCoreStartupParameter.bCPUThread)
VideoFifo_CheckSwapRequest();
@@ -110,7 +110,7 @@ void VideoBackendHLE::Video_BeginField(u32 xfbAddr, FieldType field, u32 fbWidth
// Run from the CPU thread (from VideoInterface.cpp)
void VideoBackendHLE::Video_EndField()
{
- if (s_PluginInitialized)
+ if (s_BackendInitialized)
{
Common::AtomicStoreRelease(s_swapRequested, true);
}
@@ -145,7 +145,7 @@ void VideoFifo_CheckEFBAccess()
u32 VideoBackendHLE::Video_AccessEFB(EFBAccessType type, u32 x, u32 y, u32 InputData)
{
- if (s_PluginInitialized)
+ if (s_BackendInitialized)
{
s_accessEFBArgs.type = type;
s_accessEFBArgs.x = x;
diff --git a/Source/Core/VideoCommon/Src/MainBase.h b/Source/Core/VideoCommon/Src/MainBase.h
index 4d0ea05dbc..ed48db4b75 100644
--- a/Source/Core/VideoCommon/Src/MainBase.h
+++ b/Source/Core/VideoCommon/Src/MainBase.h
@@ -4,7 +4,7 @@
#include "CommonTypes.h"
-extern bool s_PluginInitialized;
+extern bool s_BackendInitialized;
extern u32 s_efbAccessRequested;
extern volatile u32 s_FifoShuttingDown;
extern volatile u32 s_swapRequested;
diff --git a/Source/Core/VideoCommon/Src/NativeVertexFormat.h b/Source/Core/VideoCommon/Src/NativeVertexFormat.h
index 0013e05845..02184fde1c 100644
--- a/Source/Core/VideoCommon/Src/NativeVertexFormat.h
+++ b/Source/Core/VideoCommon/Src/NativeVertexFormat.h
@@ -89,7 +89,7 @@ struct PortableVertexDeclaration
};
// The implementation of this class is specific for GL/DX, so NativeVertexFormat.cpp
-// is in the respective plugin, not here in VideoCommon.
+// is in the respective backend, not here in VideoCommon.
// Note that this class can't just invent arbitrary vertex formats out of its input -
// all the data loading code must always be made compatible.
diff --git a/Source/Core/VideoCommon/Src/OpcodeDecoding.cpp b/Source/Core/VideoCommon/Src/OpcodeDecoding.cpp
index 47d3fbd4ac..f30bfd0b41 100644
--- a/Source/Core/VideoCommon/Src/OpcodeDecoding.cpp
+++ b/Source/Core/VideoCommon/Src/OpcodeDecoding.cpp
@@ -124,7 +124,7 @@ void InterpretDisplayList(u32 address, u32 size)
g_pVideoData = old_pVideoData;
}
-// Defer to plugin-specific DL cache.
+// Defer to backend-specific DL cache.
extern bool HandleDisplayList(u32 address, u32 size);
void ExecuteDisplayList(u32 address, u32 size)
diff --git a/Source/Core/VideoCommon/Src/OpcodeDecoding.h b/Source/Core/VideoCommon/Src/OpcodeDecoding.h
index db83a8a554..9989f0fd24 100644
--- a/Source/Core/VideoCommon/Src/OpcodeDecoding.h
+++ b/Source/Core/VideoCommon/Src/OpcodeDecoding.h
@@ -44,7 +44,7 @@
#define GX_DRAW_LINES 0x5 // 0xA8
#define GX_DRAW_LINE_STRIP 0x6 // 0xB0
#define GX_DRAW_POINTS 0x7 // 0xB8
-#define GX_DRAW_NONE 0x1; //Tis is a fake value to used in the plugins
+#define GX_DRAW_NONE 0x1; //Tis is a fake value to used in the backends
void OpcodeDecoder_Init();
void OpcodeDecoder_Shutdown();
void OpcodeDecoder_Run(bool skipped_frame);
diff --git a/Source/Core/VideoCommon/Src/OpenCL.cpp b/Source/Core/VideoCommon/Src/OpenCL.cpp
index d1658ae486..0fc18017af 100644
--- a/Source/Core/VideoCommon/Src/OpenCL.cpp
+++ b/Source/Core/VideoCommon/Src/OpenCL.cpp
@@ -15,7 +15,7 @@
// Official SVN repository and contact information can be found at
// http://code.google.com/p/dolphin-emu/
-// TODO: Make a more centralized version of this (for now every plugin that will use it will create its own context, which is weird). An object maybe?
+// TODO: Make a more centralized version of this (for now every backend that will use it will create its own context, which is weird). An object maybe?
#include "OpenCL.h"
#include "Common.h"
diff --git a/Source/Core/VideoCommon/Src/PixelEngine.cpp b/Source/Core/VideoCommon/Src/PixelEngine.cpp
index 05fc65ae12..9aff12a780 100644
--- a/Source/Core/VideoCommon/Src/PixelEngine.cpp
+++ b/Source/Core/VideoCommon/Src/PixelEngine.cpp
@@ -342,13 +342,13 @@ void SetToken_OnMainThread(u64 userdata, int cyclesLate)
//{
g_bSignalTokenInterrupt = true;
//_dbg_assert_msg_(PIXELENGINE, (CommandProcessor::fifo.PEToken == (userdata&0xFFFF)), "WTF? BPMEM_PE_TOKEN_INT_ID's token != BPMEM_PE_TOKEN_ID's token" );
- INFO_LOG(PIXELENGINE, "VIDEO Plugin raises INT_CAUSE_PE_TOKEN (btw, token: %04x)", CommandProcessor::fifo.PEToken);
+ INFO_LOG(PIXELENGINE, "VIDEO Backend raises INT_CAUSE_PE_TOKEN (btw, token: %04x)", CommandProcessor::fifo.PEToken);
UpdateInterrupts();
CommandProcessor::interruptTokenWaiting = false;
IncrementCheckContextId();
//}
//else
- // LOGV(PIXELENGINE, 1, "VIDEO Plugin wrote token: %i", CommandProcessor::fifo.PEToken);
+ // LOGV(PIXELENGINE, 1, "VIDEO Backend wrote token: %i", CommandProcessor::fifo.PEToken);
}
void SetFinish_OnMainThread(u64 userdata, int cyclesLate)
diff --git a/Source/Core/VideoCommon/Src/PixelEngine.h b/Source/Core/VideoCommon/Src/PixelEngine.h
index 9bbf277055..dd0304fbe1 100644
--- a/Source/Core/VideoCommon/Src/PixelEngine.h
+++ b/Source/Core/VideoCommon/Src/PixelEngine.h
@@ -75,7 +75,7 @@ void Read16(u16& _uReturnValue, const u32 _iAddress);
void Write16(const u16 _iValue, const u32 _iAddress);
void Write32(const u32 _iValue, const u32 _iAddress);
-// gfx plugin support
+// gfx backend support
void SetToken(const u16 _token, const int _bSetTokenAcknowledge);
void SetFinish(void);
void ResetSetFinish(void);
diff --git a/Source/Core/VideoCommon/Src/VertexManagerBase.h b/Source/Core/VideoCommon/Src/VertexManagerBase.h
index 258d7e0c67..12dc02ae4b 100644
--- a/Source/Core/VideoCommon/Src/VertexManagerBase.h
+++ b/Source/Core/VideoCommon/Src/VertexManagerBase.h
@@ -10,15 +10,15 @@ public:
enum
{
- // values from OGL plugin
+ // values from OGL backend
//MAXVBUFFERSIZE = 0x1FFFF,
//MAXIBUFFERSIZE = 0xFFFF,
- // values from DX9 plugin
+ // values from DX9 backend
//MAXVBUFFERSIZE = 0x50000,
//MAXIBUFFERSIZE = 0xFFFF,
- // values from DX11 plugin
+ // values from DX11 backend
MAXVBUFFERSIZE = 0x50000,
MAXIBUFFERSIZE = 0x10000,
};
diff --git a/Source/Core/VideoCommon/Src/VideoCommon.h b/Source/Core/VideoCommon/Src/VideoCommon.h
index 4084773470..b0e01012fd 100644
--- a/Source/Core/VideoCommon/Src/VideoCommon.h
+++ b/Source/Core/VideoCommon/Src/VideoCommon.h
@@ -80,7 +80,7 @@ struct EFBRectangle : public MathUtil::Rectangle<int>
struct TargetRectangle : public MathUtil::Rectangle<int>
{
#ifdef _WIN32
- // Only used by D3D plugin.
+ // Only used by D3D backend.
const RECT *AsRECT() const
{
// The types are binary compatible so this works.
diff --git a/Source/Core/VideoCommon/Src/VideoConfig.cpp b/Source/Core/VideoCommon/Src/VideoConfig.cpp
index 42be83cf32..3f8713e825 100644
--- a/Source/Core/VideoCommon/Src/VideoConfig.cpp
+++ b/Source/Core/VideoCommon/Src/VideoConfig.cpp
@@ -222,7 +222,7 @@ void VideoConfig::GameIniLoad(const char *ini_file)
void VideoConfig::VerifyValidity()
{
// TODO: Check iMaxAnisotropy value
- if (iAdapter >= backend_info.Adapters.size()) iAdapter = 0;
+ if (iAdapter >= (int)backend_info.Adapters.size()) iAdapter = 0;
if (!backend_info.bSupportsEFBToRAM) bCopyEFBToTexture = true;
if (iMultisampleMode < 0 || iMultisampleMode >= (int)backend_info.AAModes.size()) iMultisampleMode = 0;
if (!backend_info.bSupportsRealXFB) bUseRealXFB = false;
diff --git a/Source/Core/VideoCommon/Src/VideoConfig.h b/Source/Core/VideoCommon/Src/VideoConfig.h
index e0eea387c5..49871e93ae 100644
--- a/Source/Core/VideoCommon/Src/VideoConfig.h
+++ b/Source/Core/VideoCommon/Src/VideoConfig.h
@@ -22,8 +22,8 @@
// at the start of every frame. Noone should ever change members of g_ActiveConfig
// directly.
-#ifndef _PLUGIN_VIDEO_CONFIG_H_
-#define _PLUGIN_VIDEO_CONFIG_H_
+#ifndef _VIDEO_CONFIG_H_
+#define _VIDEO_CONFIG_H_
#include "Common.h"
#include "VideoCommon.h"
@@ -173,4 +173,4 @@ void UpdateActiveConfig();
void ComputeDrawRectangle(int backbuffer_width, int backbuffer_height, bool flip, TargetRectangle *rc);
-#endif // _PLUGIN_VIDEO_CONFIG_H_
+#endif // _VIDEO_CONFIG_H_
diff --git a/Source/Core/Core/Src/OnFrame.h b/Source/Core/Core/Src/OnFrame.h
index c7eabe4fbd..ddb7755179 100644
--- a/Source/Core/Core/Src/OnFrame.h
+++ b/Source/Core/Core/Src/OnFrame.h
@@ -81,9 +81,9 @@ struct DTMHeader {
u32 numRerecords; // Number of rerecords/'cuts' of this TAS
u8 author[32]; // Author's name (encoded in UTF-8)
- u8 videoPlugin[16]; // UTF-8 representation of the video plugin
- u8 audioPlugin[16]; // UTF-8 representation of the audio plugin
- u8 padPlugin[16]; // UTF-8 representation of the input plugin
+ u8 videoBackend[16]; // UTF-8 representation of the video backend
+ u8 audioEmulator[16]; // UTF-8 representation of the audio emulator
+ u8 padBackend[16]; // UTF-8 representation of the input backend
u8 padding[7]; // Padding to align the header to 1024 bits
diff --git a/Source/Core/DolphinWX/Src/Frame.cpp b/Source/Core/DolphinWX/Src/Frame.cpp
index 71e8301937..92e75a15d9 100644
--- a/Source/Core/DolphinWX/Src/Frame.cpp
+++ b/Source/Core/DolphinWX/Src/Frame.cpp
@@ -104,7 +104,7 @@ HWND MSWGetParent_(HWND Parent)
#endif
// ---------------
// The CPanel class to receive MSWWindowProc messages from the video plugin.
extern CFrame* main_frame;
@@ -254,8 +254,8 @@ EVT_MENU(IDM_RECORDREADONLY, CFrame::OnRecordReadOnly)
EVT_MENU(IDM_FRAMESTEP, CFrame::OnFrameStep)
EVT_MENU(IDM_SCREENSHOT, CFrame::OnScreenshot)
EVT_MENU(wxID_PREFERENCES, CFrame::OnConfigMain)
-EVT_MENU(IDM_CONFIG_GFX_PLUGIN, CFrame::OnConfigGFX)
-EVT_MENU(IDM_CONFIG_DSP_PLUGIN, CFrame::OnConfigDSP)
+EVT_MENU(IDM_CONFIG_GFX_BACKEND, CFrame::OnConfigGFX)
+EVT_MENU(IDM_CONFIG_DSP_EMULATOR, CFrame::OnConfigDSP)
EVT_MENU(IDM_CONFIG_PAD_PLUGIN, CFrame::OnConfigPAD)
EVT_MENU(IDM_CONFIG_WIIMOTE_PLUGIN, CFrame::OnConfigWiimote)
EVT_MENU(IDM_CONFIG_HOTKEYS, CFrame::OnConfigHotkey)
@@ -974,7 +974,7 @@ void CFrame::OnKeyDown(wxKeyEvent& event)
ConnectWiimote(WiimoteId, connect);
}
// Send the OSD hotkeys to the video plugin
if (event.GetKeyCode() >= '3' && event.GetKeyCode() <= '7' && event.GetModifiers() == wxMOD_NONE)
{
#ifdef _WIN32
@@ -983,7 +983,7 @@ void CFrame::OnKeyDown(wxKeyEvent& event)
X11Utils::SendKeyEvent(X11Utils::XDisplayFromHandle(GetHandle()), event.GetKeyCode());
#endif
}
// Send the freelook hotkeys to the video plugin
if ((event.GetKeyCode() == ')' || event.GetKeyCode() == '(' ||
event.GetKeyCode() == '0' || event.GetKeyCode() == '9' ||
event.GetKeyCode() == 'W' || event.GetKeyCode() == 'S' ||
@@ -104,7 +104,7 @@ HWND MSWGetParent_(HWND Parent)
#endif
// ---------------
-// The CPanel class to receive MSWWindowProc messages from the video plugin.
+// The CPanel class to receive MSWWindowProc messages from the video backend.
extern CFrame* main_frame;
@@ -974,7 +974,7 @@ void CFrame::OnKeyDown(wxKeyEvent& event)
ConnectWiimote(WiimoteId, connect);
}
- // Send the OSD hotkeys to the video plugin
+ // Send the OSD hotkeys to the video backend
if (event.GetKeyCode() >= '3' && event.GetKeyCode() <= '7' && event.GetModifiers() == wxMOD_NONE)
{
@@ -983,7 +983,7 @@ void CFrame::OnKeyDown(wxKeyEvent& event)
#endif
}
- // Send the freelook hotkeys to the video plugin
+ // Send the freelook hotkeys to the video backend
if ((event.GetKeyCode() == ')' || event.GetKeyCode() == '(' ||
event.GetKeyCode() == '0' || event.GetKeyCode() == '9' ||
diff --git a/Source/Core/VideoCommon/Src/CommandProcessor.cpp b/Source/Core/VideoCommon/Src/CommandProcessor.cpp
index 05ebd1ede2..1391ed657b 100644
--- a/Source/Core/VideoCommon/Src/CommandProcessor.cpp
+++ b/Source/Core/VideoCommon/Src/CommandProcessor.cpp
@@ -36,7 +36,7 @@
// PPC have a frame-finish watchdog. Handled by system timming stuff like the decrementer.
// (DualCore mode): I have observed, after ZTP logos, a fifo-recovery start when DECREMENTER_EXCEPTION is throwned.
// The frame setting (by GP) took too much time and didn't finish properly due to this watchdog.
-// Faster GX plugins required, indeed :p
+// Faster GX backends required, indeed :p
// * BPs are needed for some game GP/CPU sync.
// But it could slowdown (MP1 at least) because our GP in DC is faster than "expected" in some area.
@@ -751,7 +751,7 @@ void CatchUpGPU()
break;
}
// read the data and send it to the VideoPlugin
// We are going to do FP math on the main thread so have to save the current state
SaveSSEState();
LoadDefaultSSEState();
@@ -808,12 +808,12 @@ void UpdateInterrupts(u64 userdata)
interruptWaiting = false;
}
-void UpdateInterruptsFromVideoPlugin(u64 userdata)
+void UpdateInterruptsFromVideoBackend(u64 userdata)
{
CoreTiming::ScheduleEvent_Threadsafe(0, et_UpdateInterrupts, userdata);
}
-void SetFifoIdleFromVideoPlugin()
+void SetFifoIdleFromVideoBackend()
{
s_fifoIdleEvent.Set();
}
@@ -901,7 +901,7 @@ void SetStatus()
if (IsOnThread())
{
interruptWaiting = true;
- CommandProcessor::UpdateInterruptsFromVideoPlugin(userdata);
+ CommandProcessor::UpdateInterruptsFromVideoBackend(userdata);
}
else
CommandProcessor::UpdateInterrupts(userdata);
@@ -751,7 +751,7 @@ void CatchUpGPU()
break;
}
- // read the data and send it to the VideoPlugin
+ // read the data and send it to the VideoBackend
// We are going to do FP math on the main thread so have to save the current state
SaveSSEState();
diff --git a/Source/Core/VideoCommon/Src/Fifo.cpp b/Source/Core/VideoCommon/Src/Fifo.cpp
index f459fd4ef6..9f0ec05187 100644
--- a/Source/Core/VideoCommon/Src/Fifo.cpp
+++ b/Source/Core/VideoCommon/Src/Fifo.cpp
@@ -148,7 +148,7 @@ void Fifo_EnterLoop()
if (!fifoStateRun) break;
// Create pointer to video data and send it to the VideoPlugin
u32 readPtr = _fifo.CPReadPointer;
u8 *uData = Memory::GetPointer(readPtr);
@@ -182,7 +182,7 @@ void Fifo_EnterLoop()
_fifo.isFifoProcesingData = false;
- CommandProcessor::SetFifoIdleFromVideoPlugin();
+ CommandProcessor::SetFifoIdleFromVideoBackend();
if (EmuRunning)
Common::YieldCPU();
@@ -148,7 +148,7 @@ void Fifo_EnterLoop()
if (!fifoStateRun) break;
- // Create pointer to video data and send it to the VideoPlugin
+ // Create pointer to video data and send it to the VideoBackend
u32 readPtr = _fifo.CPReadPointer;
u8 *uData = Memory::GetPointer(readPtr);